import 'package:dashboard/jsongetter.dart';
import 'package:enhanced_future_builder/enhanced_future_builder.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'shared.dart';
import 'postnode.dart';
import 'communitymetagraph.dart';

class CommunityGraph extends StatefulWidget {
  CommunityGraph(this.communityname, this.community);
  final String communityname;
  final Map<String, dynamic> community;

  _CommunityGraphState createState() =>
      _CommunityGraphState(communityname, community);
}

class _CommunityGraphState extends State<CommunityGraph> {
  _CommunityGraphState(this.communityname, this.community);
  final String communityname;
  final Map<String, dynamic> community;

  build(BuildContext context) {
    return Container(
      width: 2000,
      height: 1000,
      //constraints: BoxConstraints.expand(),
      child: InteractiveViewer(
        constrained: true,
        boundaryMargin: EdgeInsets.all(100),
        minScale: 0.01,
        maxScale: 5.6,
        child: GraphView(
          graph: communityGraph,
          algorithm: FruchtermanReingoldAlgorithm(),
          paint: Paint()
            ..color = Colors.black
            ..strokeWidth = 1
            ..style = PaintingStyle.stroke,
        ),
      ),
    );
  }

  final Graph communityGraph = Graph();

  @override
  void initState() {
    super.initState();

    final Node communityNode =
        Node(getCommunityNode(communityname, community["trust"]));

    communityGraph.addNode(communityNode);

    List<dynamic> posts = community["posts"];

    for (Map<String, dynamic> post in posts) {
      AddNode(communityNode, PostNode(post));
    }
  }

  void AddNode(Node parentNode, Widget child) {
    final Node childNode = Node(child);

    communityGraph.addNode(childNode);

    communityGraph.addEdge(parentNode, childNode,
        paint: Paint()..color = Colors.black);
  }

  Widget getCommunityNode(String name, double trustvalue) {
    return Container(
        padding: EdgeInsets.all(16),
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(4),
          boxShadow: [
            BoxShadow(
                color: Colors.orange[400] ?? Colors.orange, spreadRadius: 1),
          ],
        ),
        width: 200,
        child: Row(
          children: [
            Expanded(
              child: Text(
                name,
                overflow: TextOverflow.ellipsis,
                style:
                    TextStyle(fontWeight: FontWeight.bold, color: Colors.black),
              ),
            ),
            Text(
              (trustvalue * 100).toString() + "%",
              style:
                  TextStyle(fontWeight: FontWeight.bold, color: Colors.green),
            ),
          ],
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
        ));
  }
}

class CommunityGraphViewPage extends StatelessWidget {
  final String communityname;
  CommunityGraphViewPage(this.communityname);
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        floatingActionButton: FloatingActionButton(
          onPressed: () => redirectToCommunityMetaGraph(context),
          child: Icon(Icons.zoom_out),
        ),
        body: Container(
          padding: EdgeInsets.all(12),
          constraints: BoxConstraints.expand(),
          child: Column(
            mainAxisSize: MainAxisSize.max,
            children: [
              Wrap(
                children: [],
              ),
              EnhancedFutureBuilder(
                  future: JsonGetter.getJson(
                      "http://live.nope-api.systems:81/communities/" +
                          communityname +
                          "/posts"),
                  rememberFutureResult: false,
                  whenDone: (result) => CommunityGraph(communityname, result),
                  whenNotDone: Container(
                      alignment: Alignment.center, child: Text("Loading..."))),
            ],
          ),
        ));
  }

  void redirectToCommunityMetaGraph(BuildContext context) {
    Navigator.push(
        context,
        MaterialPageRoute(
          builder: (context) => CommunityMetaGraphViewPage(),
        ));
  }
}
