import 'package:dashboard/jsongetter.dart';
import 'package:dashboard/postnode.dart';
import 'package:dashboard/shared.dart';
import 'package:flutter/material.dart';
import 'shared.dart';
import 'communitygraph.dart';
import 'trustcolorcalculator.dart';
import 'package:enhanced_future_builder/enhanced_future_builder.dart';

class CommunityMetaGraph extends StatefulWidget {
  final Map<String, dynamic> communities;
  CommunityMetaGraph(this.communities);

  _CommunityMetaGraphState createState() =>
      _CommunityMetaGraphState(this.communities);
}

class _CommunityMetaGraphState extends State<CommunityMetaGraph> {
  final Map<String, dynamic> communities;
  int postNodeCount = 10; // Nr of postNodes displayed
  _CommunityMetaGraphState(this.communities);

  Widget build(BuildContext context) {
    return Container(
      width: 2000,
      height: 1000,
      //constraints: BoxConstraints.expand(),
      child: InteractiveViewer(
        constrained: true,
        boundaryMargin: EdgeInsets.all(100),
        minScale: 0.01,
        maxScale: 5.6,
        child: GraphView(
          graph: communityMetaGraph,
          algorithm: FruchtermanReingoldAlgorithm(),
          paint: Paint()
            ..color = Colors.black
            ..strokeWidth = 1
            ..style = PaintingStyle.stroke,
        ),
      ),
    );
  }

  final Graph communityMetaGraph = Graph();
  final Node metaNode = Node(Container(
    width: 10,
    height: 10,
    color: Colors.red,
  ));
  final Node placeholderNode = Node(Container());

  void initState() {
    super.initState();
    communityMetaGraph.addNode(metaNode);

    int communityCount = 0;
    communities.forEach((name, community) {
      print("ay");
      if (communityCount > 10) {
        return;
      }
      communityCount++;
      List<dynamic> posts = community["posts"];

      Node communityNode = getCommunityNode(name, community);
      communityMetaGraph.addEdge(metaNode, communityNode,
          paint: Paint()..color = Colors.transparent);

      int i = 0;
      for (Map<String, dynamic> post in posts) {
        print("hoi");
        if (i > postNodeCount) {
          break;
        }
        Node postNode = Node(PostNode(post));
        communityMetaGraph.addEdge(communityNode, postNode,
            paint: Paint()..color = Colors.black);
        i++;
      }
    });
  }

  Node getCommunityNode(String name, Map<String, dynamic> community) {
    return Node(GestureDetector(
        child: Container(
            padding: EdgeInsets.all(16),
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(4),
              boxShadow: [
                BoxShadow(
                    color: Colors.orange[400] ?? Colors.orange,
                    spreadRadius: 1),
              ],
            ),
            width: 200,
            child: Row(
              children: [
                Expanded(
                  child: Text(
                    name,
                    overflow: TextOverflow.ellipsis,
                    style: TextStyle(
                        fontWeight: FontWeight.bold, color: Colors.black),
                  ),
                ),
                Text(
                  (community["trust"] * 100).toString() + "%",
                  style: TextStyle(
                      fontWeight: FontWeight.bold,
                      color: TrustColorCalculator.calculateTrustColor(
                          community["trust"])),
                ),
              ],
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
            ))));
  }
}

class CommunityMetaGraphViewPage extends StatelessWidget {
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        //floatingActionButton: FloatingActionButton(
        //  onPressed: () => print("hoe"),
        //  child: Icon(Icons.zoom_in),
        //),
        body: Container(
          padding: EdgeInsets.all(12),
          constraints: BoxConstraints.expand(),
          child: Column(
            mainAxisSize: MainAxisSize.max,
            children: [
              Wrap(
                children: [],
              ),
              EnhancedFutureBuilder(
                future: getCommunitywithPosts(),
                rememberFutureResult: true,
                whenDone: (communities) => CommunityMetaGraph(communities),
                whenNotDone: Container(
                  alignment: Alignment.center,
                  child: Text("Loading..."),
                ),
              ),
            ],
          ),
        ));
  }

  Future<Map<String, dynamic>> getCommunitywithPosts() async {
    Map<String, dynamic> communities =
        await JsonGetter.getJson("http://live.nope-api.systems:81/communities");

    Map<String, dynamic> communitiesWithPosts = {};
    communities.forEach((community, value) async {
      communitiesWithPosts[community] = await JsonGetter.getJson(
          "http://live.nope-api.systems:81/communities/" +
              community +
              "/posts");
    });
    print("fml");
    return communitiesWithPosts;
  }
}
