import 'package:apex_flutter_sdk/apex_flutter_sdk.dart';
import 'package:dashboard/main.dart';
import 'package:dashboard/usergraph.dart';
import 'package:flutter/material.dart';
import 'trustcolorcalculator.dart';
import 'communitygraph.dart';

class PostNode extends StatelessWidget {
  final Map<String, dynamic> post;
  PostNode(this.post);

  Color trustColor = Colors.transparent;

  Widget build(BuildContext context) {
    trustColor =
        TrustColorCalculator.calculateTrustColor(post["percentage_upvoted"]);
    return GestureDetector(
      onTap: () => redirectToPost(context),
      child: Container(
          padding: EdgeInsets.all(16),
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(4),
            boxShadow: [
              BoxShadow(
                  color: Colors.grey[300] ?? Colors.grey, spreadRadius: 1),
            ],
          ),
          width: 200,
          child: Row(
            children: [
              Expanded(
                child: Text(
                  post["title"] != "" ? post["title"] : post["content"],
                  overflow: TextOverflow.ellipsis,
                  style: TextStyle(
                      fontWeight: FontWeight.bold, color: Colors.black),
                ),
              ),
              Text(
                (post["percentage_upvoted"] * 100).toString() + "%",
                style:
                    TextStyle(fontWeight: FontWeight.bold, color: trustColor),
              ),
            ],
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
          )),
    );
  }

  void redirectToPost(BuildContext context) {
    Navigator.push(
        context,
        MaterialPageRoute(
          builder: (context) => PostNodeTooltip(post, this.trustColor),
        ));
  }
}

class PostNodeTooltip extends StatelessWidget {
  PostNodeTooltip(this.post, this.trustColor);
  final Map<String, dynamic> post;

  final Color trustColor;

  double titleSize = 22;

  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
          padding: EdgeInsets.fromLTRB(12, 8, 12, 8),
          constraints: BoxConstraints.expand(),
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(4),
            boxShadow: [
              BoxShadow(color: Colors.grey[100] ?? Colors.grey, spreadRadius: 1)
            ],
          ),
          child: Column(
            children: [
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Row(
                    children: [
                      Container(
                        child: Text(
                          post["title"] != "" ? post["title"] : "Comment",
                          overflow: TextOverflow.fade,
                          style: TextStyle(
                            fontWeight: FontWeight.bold,
                            color: Colors.black,
                            fontSize: titleSize,
                          ),
                        ),
                        //constraints: BoxConstraints.expand(),
                      ),
                    ],
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Padding(
                        padding: const EdgeInsets.fromLTRB(0, 0, 25, 0),
                        child: TextButton(
                          onPressed: () => redirectToUserGraph(context),
                          child: Text(
                            post["user_id"],
                            style: TextStyle(
                              fontWeight: FontWeight.bold,
                              color: Colors.black,
                              fontSize: titleSize,
                            ),
                          ),
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.fromLTRB(25, 0, 25, 0),
                        child: TextButton(
                          onPressed: () => redirectToCommunityGraph(context),
                          child: Text(
                            post["subreddit"],
                            style: TextStyle(
                              fontWeight: FontWeight.bold,
                              color: Colors.black,
                              fontSize: titleSize,
                            ),
                          ),
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.fromLTRB(25, 0, 25, 0),
                        child: Text(
                          (post["percentage_upvoted"] * 100).toString() + "%",
                          style: TextStyle(
                            fontWeight: FontWeight.bold,
                            color: trustColor,
                            fontSize: titleSize,
                          ),
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.fromLTRB(25, 0, 0, 0),
                        child: Material(
                          color: Colors.red[400] ?? Colors.red,
                          child: IconButton(
                            onPressed: () => Navigator.pop(context),
                            icon: Icon(Icons.close),
                          ),
                        ),
                      ),
                    ],
                  )
                ],
              ),
              Container(
                //constraints: BoxConstraints.expand(),
                padding: EdgeInsets.fromLTRB(0, 10, 0, 0),
                child: Text(
                  post["content"],
                  overflow: TextOverflow.fade,
                  style: TextStyle(color: Colors.black, fontSize: 15),
                ),
              ),
            ],
          )),
    );
  }

  void redirectToUserGraph(BuildContext context) {
    Navigator.push(
        context,
        MaterialPageRoute(
          builder: (context) => UserGraphViewPage(post["user_id"]),
        ));
  }

  void redirectToCommunityGraph(BuildContext context) {
    Navigator.push(
        context,
        MaterialPageRoute(
          builder: (context) => CommunityGraphViewPage(post["subreddit"]),
        ));
  }
}
